PALM-meteo: palmmeteo/config.py File Reference

PALM-meteo

Loading...
Searching...
No Matches
Classes | Namespaces | Functions | Variables
config.py File Reference

## Classes
class | palmmeteo.config.ConfigError
class | palmmeteo.config.ConfigObj

## Namespaces
namespace | palmmeteo
namespace | palmmeteo.config

## Functions
| palmmeteo.config.parse_duration (section, item, value=None)
| palmmeteo.config.load_config (argv)

## Variables
dict | palmmeteo.config.duration_units
| palmmeteo.config.cfg = ConfigObj()